dynamic_ui_renderer library
Classes
- ActionHandler
- Handles all button actions
- ButtonAction
- Model for handling button actions
- DropdownOption
- Represents a dropdown option
- DynamicCheckboxField
- Dynamic checkbox field widget
- DynamicDateField
- Dynamic date field widget
- DynamicDropdownField
- Dynamic dropdown field widget
- DynamicEmailField
- Dynamic email field widget (specialized text field)
- DynamicForm
- Main form widget that renders dynamic forms from JSON
- DynamicNumberField
- Dynamic number field widget (specialized text field)
- DynamicPasswordField
- Dynamic password field widget (specialized text field)
- DynamicPhoneField
- Dynamic phone field widget
- DynamicTextField
- Dynamic text field widget
- DynamicUIRenderer
- The main entry point for the dynamic_ui_renderer package
- FormController
- Manages form state and validation
- FormFieldConfig
- Represents a form field configuration
- UIComponent
- Represents a UI component parsed from JSON This is the core data structure that represents any UI element
- UIUtils
- Utility functions for parsing JSON properties
- ValidationRule
- Represents a validation rule
Enums
- ActionType
- Types of actions that can be performed
- FieldType
- Types of form fields supported
- ValidationType
- Validation rule types
Typedefs
-
FormSubmitCallback
= void Function(String formId, Map<
String, dynamic> formData) -
FormSubmitListener
= void Function(Map<
String, dynamic> formData)